@@ -41,7 +41,10 @@ mapb_rgb = { 'red'   : ((0.0, 0.0, 0.0),
 #(0,0)(0.25,1)(0.5,0)(0.75,0)(1,1)
 
 mapb = LinearSegmentedColormap('b_ds9',mapb_rgb)
-plt.register_cmap(cmap=mapb)
+try:
+    plt.register_cmap(cmap=mapb)
+except:
+    matplotlib.colormaps.register(cmap=mapb)
 
 def ellipse (x0, y0, sma, eps, pa, step=400,
              linef='k-', linew=4, plotr='no', AX=None):
@@ -380,7 +383,7 @@ def figure(image, cent=[0,0], delta=[0,0], limt=[0,0,0], cmap=['jet'],
            pgrid=['off','k'], bbox='tight',
            cont='none', imax='no', imin='no', ncont=10, nivels=None,
            sigmag=2.5, contc=None, contl='no', contf='%3.0f', contsz=10,
-           contxt=None, contls='solid',
+           contxt=None, contls='solid', contlw=1,
            cbaropt = 0, cbar=None, cbarlb=None, cbartk=None, cbarl=None,
            barinvt='no',
            aextend='on', aspect='equal', interpolation = 'none', alpha=1,
@@ -496,7 +499,7 @@ def figure(image, cent=[0,0], delta=[0,0], limt=[0,0,0], cmap=['jet'],
             else:
                 kernel = Gaussian2DKernel(stddev=sigmag)
             print ('\nIn order to plot the contours was applied a Gaussian' +
-                   + ' smoothing')
+                   ' smoothing')
             smooth = convolve(temp, kernel)
             smooth[np.isnan(temp)]=np.nan
         else:
@@ -505,7 +508,8 @@ def figure(image, cent=[0,0], delta=[0,0], limt=[0,0,0], cmap=['jet'],
                     ' smoothing')
         print('Contour intensities: ', nivels)
         CS = AX.contour(smooth, nivels, origin='lower', cmap=None,
-                       extent=aextend, colors=contc, linestyles=contls)
+                        extent=aextend, colors=contc, linestyles=contls,
+                        linewidths=contlw)
 
         # Contour levels
         if contxt != None:
